==> jc-1.4.0.tar.gz: javax/swing/text/StyledEditorKit__24UnderlineAction.h <==
// public class javax.swing.text.StyledEditorKit$UnderlineAction

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class f02353a2de7b0e85 javax_swing_AbstractAction
// @dep_class 269e09938263c482 javax_swing_text_StyledEditorKit__24StyledTextAction
// @dep_class ed40ae566b30a761 javax_swing_text_StyledEditorKit__24UnderlineAction
// @dep_class ebc1c295cb90fd47 javax_swing_text_TextAction

// header file dependencies
// @dep_header javax_swing_text_StyledEditorKit__24StyledTextAction

#include "javax/swing/text/StyledEditorKit__24StyledTextAction.h"

#ifndef _JC_javax_swing_text_StyledEditorKit__24UnderlineAction_H_
#define _JC_javax_swing_text_StyledEditorKit__24UnderlineAction_H_

// Forward structure declarations
struct _jc_java_awt_event_ActionEvent$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_swing_text_StyledEditorKit__24UnderlineAction$sub_refs	_jc_javax_swing_text_StyledEditorKit__24UnderlineAction$sub_refs;
typedef struct _jc_javax_swing_text_StyledEditorKit__24UnderlineAction$sub_nonrefs	_jc_javax_swing_text_StyledEditorKit__24UnderlineAction$sub_nonrefs;
typedef struct _jc_javax_swing_text_StyledEditorKit__24UnderlineAction$refs	_jc_javax_swing_text_StyledEditorKit__24UnderlineAction$refs;
typedef struct _jc_javax_swing_text_StyledEditorKit__24UnderlineAction$nonrefs	_jc_javax_swing_text_StyledEditorKit__24UnderlineAction$nonrefs;
typedef struct _jc_javax_swing_text_StyledEditorKit__24UnderlineAction$object	_jc_javax_swing_text_StyledEditorKit__24UnderlineAction$object;

typedef const struct _jc_javax_swing_text_StyledEditorKit__24UnderlineAction$vmethods	_jc_javax_swing_text_StyledEditorKit__24UnderlineAction$vmethods;
typedef const struct _jc_javax_swing_text_StyledEditorKit__24UnderlineAction$vtable	_jc_javax_swing_text_StyledEditorKit__24UnderlineAction$vtable;
typedef const struct _jc_javax_swing_text_StyledEditorKit__24UnderlineAction$vtype	_jc_javax_swing_text_StyledEditorKit__24UnderlineAction$vtype;

// Constructors
extern void _jc_javax_swing_text_StyledEditorKit__24UnderlineAction$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_text_StyledEditorKit__24UnderlineAction$object *);

// Virtual methods
extern void _jc_javax_swing_text_StyledEditorKit__24UnderlineAction$method$actionPerformed$9046a9754e643ffd(_jc_env *, struct _jc_javax_swing_text_StyledEditorKit__24UnderlineAction$object *, struct _jc_java_awt_event_ActionEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_text_StyledEditorKit__24UnderlineAction$method_info$actionPerformed$9046a9754e643ffd;

// Virtual methods structure
struct _jc_javax_swing_text_StyledEditorKit__24UnderlineAction$vmethods {
	void	(*actionPerformed$9046a9754e643ffd)(_jc_env *, struct _jc_javax_swing_text_StyledEditorKit__24UnderlineAction$object *, struct _jc_java_awt_event_ActionEvent$object *);
};

// Vtable
struct _jc_javax_swing_text_StyledEditorKit__24UnderlineAction$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_AbstractAction$vmethods	javax_swing_AbstractAction;
	_jc_javax_swing_text_TextAction$vmethods	javax_swing_text_TextAction;
	_jc_javax_swing_text_StyledEditorKit__24StyledTextAction$vmethods	javax_swing_text_StyledEditorKit__24StyledTextAction;
	_jc_javax_swing_text_StyledEditorKit__24UnderlineAction$vmethods	javax_swing_text_StyledEditorKit__24UnderlineAction;
};

// Vtype
struct _jc_javax_swing_text_StyledEditorKit__24UnderlineAction$vtype {
	_jc_type			type;
	_jc_javax_swing_text_StyledEditorKit__24UnderlineAction$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_text_StyledEditorKit__24UnderlineAction$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_text_StyledEditorKit__24UnderlineAction$refs {
    _jc_javax_swing_text_StyledEditorKit__24UnderlineAction$sub_refs	javax_swing_text_StyledEditorKit__24UnderlineAction;
    _jc_javax_swing_text_StyledEditorKit__24StyledTextAction$sub_refs	javax_swing_text_StyledEditorKit__24StyledTextAction;
    _jc_javax_swing_text_TextAction$sub_refs	javax_swing_text_TextAction;
    _jc_javax_swing_AbstractAction$sub_refs	javax_swing_AbstractAction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_text_StyledEditorKit__24UnderlineAction$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_text_StyledEditorKit__24UnderlineAction$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_AbstractAction$sub_nonrefs	javax_swing_AbstractAction;
    _jc_javax_swing_text_TextAction$sub_nonrefs	javax_swing_text_TextAction;
    _jc_javax_swing_text_StyledEditorKit__24StyledTextAction$sub_nonrefs	javax_swing_text_StyledEditorKit__24StyledTextAction;
    _jc_javax_swing_text_StyledEditorKit__24UnderlineAction$sub_nonrefs	javax_swing_text_StyledEditorKit__24UnderlineAction;
};

// Object instance structure
struct _jc_javax_swing_text_StyledEditorKit__24UnderlineAction$object {
	_jc_javax_swing_text_StyledEditorKit__24UnderlineAction$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_text_StyledEditorKit__24UnderlineAction$vtype	*vtype;
	_jc_javax_swing_text_StyledEditorKit__24UnderlineAction$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_text_StyledEditorKit__24UnderlineAction$vtype _jc_javax_swing_text_StyledEditorKit__24UnderlineAction$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_text_StyledEditorKit__24UnderlineAction, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_text_StyledEditorKit__24UnderlineAction$class_object;

#endif	/* _JC_javax_swing_text_StyledEditorKit__24UnderlineAction_H_ */

==> jc-1.4.5.tar.gz: javax/swing/text/StyledEditorKit__24UnderlineAction.h <==
// public class javax.swing.text.StyledEditorKit$UnderlineAction

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class f02353a2de7b0e85 javax_swing_AbstractAction
// @dep_class 269e09938263c482 javax_swing_text_StyledEditorKit__24StyledTextAction
// @dep_class ed40ae566b30a761 javax_swing_text_StyledEditorKit__24UnderlineAction
// @dep_class ebc1c295cb90fd47 javax_swing_text_TextAction

// header file dependencies
// @dep_header javax_swing_text_StyledEditorKit__24StyledTextAction

#include "javax/swing/text/StyledEditorKit__24StyledTextAction.h"

#ifndef _JC_javax_swing_text_StyledEditorKit__24UnderlineAction_H_
#define _JC_javax_swing_text_StyledEditorKit__24UnderlineAction_H_

// Forward structure declarations
struct _jc_java_awt_event_ActionEvent$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_swing_text_StyledEditorKit__24UnderlineAction$sub_refs	_jc_javax_swing_text_StyledEditorKit__24UnderlineAction$sub_refs;
typedef struct _jc_javax_swing_text_StyledEditorKit__24UnderlineAction$sub_nonrefs	_jc_javax_swing_text_StyledEditorKit__24UnderlineAction$sub_nonrefs;
typedef struct _jc_javax_swing_text_StyledEditorKit__24UnderlineAction$refs	_jc_javax_swing_text_StyledEditorKit__24UnderlineAction$refs;
typedef struct _jc_javax_swing_text_StyledEditorKit__24UnderlineAction$nonrefs	_jc_javax_swing_text_StyledEditorKit__24UnderlineAction$nonrefs;
typedef struct _jc_javax_swing_text_StyledEditorKit__24UnderlineAction$object	_jc_javax_swing_text_StyledEditorKit__24UnderlineAction$object;

typedef const struct _jc_javax_swing_text_StyledEditorKit__24UnderlineAction$vmethods	_jc_javax_swing_text_StyledEditorKit__24UnderlineAction$vmethods;
typedef const struct _jc_javax_swing_text_StyledEditorKit__24UnderlineAction$vtable	_jc_javax_swing_text_StyledEditorKit__24UnderlineAction$vtable;
typedef const struct _jc_javax_swing_text_StyledEditorKit__24UnderlineAction$vtype	_jc_javax_swing_text_StyledEditorKit__24UnderlineAction$vtype;

// Constructors
extern void _jc_javax_swing_text_StyledEditorKit__24UnderlineAction$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_text_StyledEditorKit__24UnderlineAction$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_text_StyledEditorKit__24UnderlineAction$method$actionPerformed$9046a9754e643ffd(_jc_env *, struct _jc_javax_swing_text_StyledEditorKit__24UnderlineAction$object *, struct _jc_java_awt_event_ActionEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_text_StyledEditorKit__24UnderlineAction$method_info$actionPerformed$9046a9754e643ffd;

// Virtual methods structure
struct _jc_javax_swing_text_StyledEditorKit__24UnderlineAction$vmethods {
	void	(*actionPerformed$9046a9754e643ffd)(_jc_env *, struct _jc_javax_swing_text_StyledEditorKit__24UnderlineAction$object *, struct _jc_java_awt_event_ActionEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_text_StyledEditorKit__24UnderlineAction$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_AbstractAction$vmethods	javax_swing_AbstractAction;
	_jc_javax_swing_text_TextAction$vmethods	javax_swing_text_TextAction;
	_jc_javax_swing_text_StyledEditorKit__24StyledTextAction$vmethods	javax_swing_text_StyledEditorKit__24StyledTextAction;
	_jc_javax_swing_text_StyledEditorKit__24UnderlineAction$vmethods	javax_swing_text_StyledEditorKit__24UnderlineAction;
};

// Vtype
struct _jc_javax_swing_text_StyledEditorKit__24UnderlineAction$vtype {
	_jc_type			type;
	_jc_javax_swing_text_StyledEditorKit__24UnderlineAction$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_text_StyledEditorKit__24UnderlineAction$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_text_StyledEditorKit__24UnderlineAction$refs {
    _jc_javax_swing_text_StyledEditorKit__24UnderlineAction$sub_refs	javax_swing_text_StyledEditorKit__24UnderlineAction;
    _jc_javax_swing_text_StyledEditorKit__24StyledTextAction$sub_refs	javax_swing_text_StyledEditorKit__24StyledTextAction;
    _jc_javax_swing_text_TextAction$sub_refs	javax_swing_text_TextAction;
    _jc_javax_swing_AbstractAction$sub_refs	javax_swing_AbstractAction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_text_StyledEditorKit__24UnderlineAction$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_text_StyledEditorKit__24UnderlineAction$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_AbstractAction$sub_nonrefs	javax_swing_AbstractAction;
    _jc_javax_swing_text_TextAction$sub_nonrefs	javax_swing_text_TextAction;
    _jc_javax_swing_text_StyledEditorKit__24StyledTextAction$sub_nonrefs	javax_swing_text_StyledEditorKit__24StyledTextAction;
    _jc_javax_swing_text_StyledEditorKit__24UnderlineAction$sub_nonrefs	javax_swing_text_StyledEditorKit__24UnderlineAction;
};

// Object instance structure
struct _jc_javax_swing_text_StyledEditorKit__24UnderlineAction$object {
	_jc_javax_swing_text_StyledEditorKit__24UnderlineAction$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_text_StyledEditorKit__24UnderlineAction$vtype	*vtype;
	_jc_javax_swing_text_StyledEditorKit__24UnderlineAction$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_text_StyledEditorKit__24UnderlineAction$vtype _jc_javax_swing_text_StyledEditorKit__24UnderlineAction$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_text_StyledEditorKit__24UnderlineAction, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_text_StyledEditorKit__24UnderlineAction$class_object;

#endif	/* _JC_javax_swing_text_StyledEditorKit__24UnderlineAction_H_ */
